==> haskell-persistent-test-2.13.1.3-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-9oj7cLNoJ4V5G7Duc2sx4b
key:                  persistent-test-2.13.1.3-9oj7cLNoJ4V5G7Duc2sx4b
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  f00866d1bc0136b28766307c6e637534
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-9oj7cLNoJ4V5G7Duc2sx4b
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.14.3-3CoFGl7CagbATKlXLaYDNP
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0 base-4.17.2.1
    blaze-html-0.9.2.0-7rraM1lSLOl2LrVAS4qxq6 bytestring-0.11.5.3
    conduit-1.3.6.1-GhV2KMoemFPB5FDryFR5X5 containers-0.6.7
    exceptions-0.10.5 hspec-2.10.9-KjMOU4OB4qFAiRTApzpdJt
    hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    http-api-data-0.5.1-BEGvnT5hQ3o69m3sBT7FeT
    monad-control-1.0.3.1-9Q6yZyzqsWl7wMwMnI2eNb
    monad-logger-0.3.42-AQcgAh9wba2AXEOYEs9uhR mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.1-ACPhqaDIO2DzaMw7Q8faI
    quickcheck-instances-0.3.30-3fWeKkjJuM84lWDnkIeaqX
    random-1.2.1.2-6Lko0US7c1TJAwLQn9MTsf
    resourcet-1.2.6-1qaZdHoBp5u2zlBnaE55JI text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-Lje61Sgnk77G867ddMqoaX
    unliftio-0.2.25.1-1uYB5ruuxlB51GjsaBkLd
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-test-2.13.1.3-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-Ie5mXa7TGBw2nSyuTYNi5N
key:                  persistent-test-2.13.1.3-Ie5mXa7TGBw2nSyuTYNi5N
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  537b3deb99ea66f05b687a5a0fbc7d5b
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-Ie5mXa7TGBw2nSyuTYNi5N
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.14.3-JT8ioqllyin7h2duLhwDbF
    aeson-2.1.2.1-PtSa2Du7ZnC9cVeQoj7Qs base-4.17.2.1
    blaze-html-0.9.2.0-7T5tBdPknWXDUJ5NeSXWzj bytestring-0.11.5.3
    conduit-1.3.6.1-KODsDTHe54N26FyzTue8CU containers-0.6.7
    exceptions-0.10.5 hspec-2.10.9-LrKv2WLw3ll63lZh5sx0BW
    hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    http-api-data-0.5.1-DDweXEaUTlK15HoSIfN6YP
    monad-control-1.0.3.1-Gw3XM64JSJ5ntrqlz8Emw
    monad-logger-0.3.42-FIB4S4nvnoBKOGKqiukiqY mtl-2.2.2
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.1-G0CObyBxLFk6otE3EH8Q2x
    quickcheck-instances-0.3.30-LSOD51KuQNN1Y1OWT4sVNd
    random-1.2.1.2-KXwyGxW8gFCDB692Rea4Jy
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-7U7lXEgv0cHELUGOzmogrd
    unliftio-0.2.25.1-4ouS4p8u42FHJEBnZmJiqL
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-HNPxulgNQi0FiQ3NUpCOne

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
